@@ -2,26 +2,33 @@ import numpy as np
 from ..helper.fitting import fit_tau
 
 
+colors = ('b', 'r', 'g', 'c', 'm', 'y', 'k')
+
+
 def plot(xf_list, hdl, q_range, offset, plot_type=3):
 
     hdl.clear()
     ax = hdl.subplots(1, 1)
 
-    n = -1
-    for xf in xf_list:
-        n += 1
+    for n, xf in enumerate(xf_list):
         s = 10 ** (offset * n)
         x = xf.fit_summary['q_val']
         y = xf.fit_summary['fit_val'][:, 0, 1]
         e = xf.fit_summary['fit_val'][:, 1, 1]
-        line = ax.errorbar(x, y/s,  yerr=e/s, fmt='o-', markersize=3,
-                           label=xf.label)
-        fit_x = xf.fit_summary['tauq_fit_line']['fit_x']
-        fit_y = xf.fit_summary['tauq_fit_line']['fit_y']
+        # remove failed fittings;
+        valid_idx = e > 0
+        x = x[valid_idx]
+        y = y[valid_idx]
+        e = e[valid_idx]
 
-        ax.plot(fit_x, fit_y / s)
-        # fit_msg.append('fn: %s, slope = %.4f, intercept = %.4f' %
-        #                (labels[n], slope, intercept))
+        color = colors[n % len(colors)]
+        line = ax.errorbar(x, y/s,  yerr=e/s, fmt='o', markersize=3,
+                           label=xf.label, color=color, mfc='white')
+
+        if xf.fit_summary.get('tauq_success', False):
+            fit_x = xf.fit_summary['tauq_fit_line']['fit_x']
+            fit_y = xf.fit_summary['tauq_fit_line']['fit_y']
+            ax.plot(fit_x, fit_y / s, color=color)
 
     ax.set_xlabel('$q (\\AA^{-1})$')
     ax.set_ylabel('$\\tau (s)$')
@@ -44,14 +51,15 @@ def plot_pre(xf_list, hdl):
     titles = ['contrast', 'tau (s)', 'stretch', 'baseline']
 
     for idx, xf in enumerate(xf_list):
+        color = colors[idx % len(colors)]
         for n in range(4):
             x = xf.fit_summary['q_val']
             y = xf.fit_summary['fit_val'][:, 0, n]
             e = xf.fit_summary['fit_val'][:, 1, n]
-            ax[n].errorbar(x, y,  yerr=e, fmt='o-', markersize=3,
-                           label=xf.label)
+            ax[n].errorbar(x, y,  yerr=e, fmt='o', markersize=3, 
+                           label=xf.label, color=color, mfc='white')
 
-        if idx == 0:
+        if idx == len(xf_list) - 1:
             bounds = xf.fit_summary['bounds']
             xmin, xmax = np.min(x), np.max(x)
             for n in range(4):
