@@ -3,19 +3,15 @@ from .viewer_ui import Ui_mainWindow as Ui
 from .viewer_kernel import ViewerKernel
 from PyQt5 import QtWidgets
 from PyQt5.QtWidgets import QFileDialog
-from PyQt5.QtCore import Qt
-
-# from pyqtgraph.Qt import QtWidgets
-# from pyqtgraph import QtCore, QtGui
 
 import os
 import numpy as np
 import sys
 import json
-
-# log file
+import shutil
 import logging
 
+
 format = logging.Formatter('%(asctime)s %(message)s')
 home_dir = os.path.join(os.path.expanduser('~'), '.xpcs_viewer')
 if not os.path.isdir(home_dir):
@@ -114,6 +110,7 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
         self.avg_job_table.clicked.connect(self.update_avg_info)
         self.show_g2_fit_summary.clicked.connect(self.show_g2_fit_summary_func)
         self.hdf_key_filter.textChanged.connect(self.show_hdf_info)
+        self.btn_g2_refit.clicked.connect(self.plot_g2)
         self.load_default_setting()
 
         # disable browse function; it freezes on linux workstation;
@@ -140,6 +137,13 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
                 new_size = (config["window_size_w"], config["window_size_h"])
                 logger.info('set mainwindow to size %s', new_size)
                 self.resize(*new_size)
+        
+        # remove joblib cache
+        cache_dir = os.path.join(os.path.expanduser('~'), '.xpcs_viewer',
+                                 'joblib/xpcs_viewer')
+        if os.path.isdir(cache_dir):
+            shutil.rmtree(cache_dir)
+
         return
 
     def get_selected_rows(self):
@@ -271,9 +275,16 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
             'plot_type': self.cb_saxs_type.currentIndex(),
             'plot_offset': self.sb_saxs_offset.value(),
             'plot_norm': self.cb_saxs_norm.currentIndex(),
-            'rows': self.get_selected_rows()
+            'rows': self.get_selected_rows(),
+            'qmin': self.saxs1d_qmin.value(),
+            'qmax': self.saxs1d_qmax.value()
         }
+        if kwargs['qmin'] >= kwargs['qmax']:
+            self.statusbar.showMessage('check qmin and qmax')
+            return
+
         self.vk.plot_saxs_1d(self.mp_saxs.hdl, **kwargs)
+        self.mp_saxs.repaint() 
 
     def init_twotime(self):
         if not self.check_status():
@@ -315,7 +326,7 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
             self.statusbar.showMessage('Twotime data not ready', 1000)
             return
 
-        if event.button == Qt.LeftButton:
+        if event.button == QtCore.Qt.LeftButton:
             self.statusbar.showMessage('Use right click to select points',
                                        1000)
             return
@@ -618,6 +629,9 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
         
         p = self.check_g2_number()
         bounds, fit_flag = self.check_number()
+        if bounds is None:
+            self.statusbar.showMessage('please check fitting bounds.')
+            return
 
         kwargs = {
             'num_col': self.sb_g2_column.value(),
@@ -856,7 +870,7 @@ class XpcsViewer(QtWidgets.QMainWindow, Ui):
                 val = float(key.text())
             except Exception:
                 key.setText(str(default_val[n]))
-                return
+                return None, None
             else:
                 vals[n] = val
 
@@ -920,7 +934,7 @@ def setup_windows_icon():
 def run():
     if os.name == 'nt':
         setup_windows_icon()
-    QtWidgets.QApplication.setAttribute(Qt.AA_EnableHighDpiScaling, True)
+    QtWidgets.QApplication.setAttribute(QtCore.Qt.AA_EnableHighDpiScaling, True)
     app = QtWidgets.QApplication(sys.argv)
     if len(sys.argv) == 2 and os.path.isdir(sys.argv[1]):
         # use arg[1] as the starting directory
